==> facebook-common-11.2.0-sources.jar: com/facebook/login/LoginResult.java <==
/*
 * Copyright (c) 2014-present, Facebook, Inc. All rights reserved.
 *
 * You are hereby granted a non-exclusive, worldwide, royalty-free license to use,
 * copy, modify, and distribute this software in source code or binary form for use
 * in connection with the web services and APIs provided by Facebook.
 *
 * As with any software that integrates with the Facebook platform, your use of
 * this software is subject to the Facebook Developer Principles and Policies
 * [http://developers.facebook.com/policy/]. This copyright notice shall be
 * included in all copies or substantial portions of the software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 * COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package com.facebook.login;

import com.facebook.AccessToken;
import java.util.Set;

/** This class shows the results of a login operation. */
public class LoginResult {
  private final AccessToken accessToken;
  private final Set<String> recentlyGrantedPermissions;
  private final Set<String> recentlyDeniedPermissions;

  /**
   * The constructor.
   *
   * @param accessToken The new access token.
   * @param recentlyGrantedPermissions The recently granted permissions.
   * @param recentlyDeniedPermissions The recently denied permissions.
   */
  public LoginResult(
      AccessToken accessToken,
      Set<String> recentlyGrantedPermissions,
      Set<String> recentlyDeniedPermissions) {
    this.accessToken = accessToken;
    this.recentlyGrantedPermissions = recentlyGrantedPermissions;
    this.recentlyDeniedPermissions = recentlyDeniedPermissions;
  }

  /**
   * Getter for the new access token.
   *
   * @return the new access token.
   */
  public AccessToken getAccessToken() {
    return accessToken;
  }

  /**
   * Getter for the recently granted permissions.
   *
   * @return the recently granted permissions.
   */
  public Set<String> getRecentlyGrantedPermissions() {
    return recentlyGrantedPermissions;
  }

  /**
   * Getter for the recently denied permissions.
   *
   * @return the recently denied permissions.
   */
  public Set<String> getRecentlyDeniedPermissions() {
    return recentlyDeniedPermissions;
  }
}

==> facebook-common-11.3.0-sources.jar: com/facebook/login/LoginResult.java <==
/*
 * Copyright (c) 2014-present, Facebook, Inc. All rights reserved.
 *
 * You are hereby granted a non-exclusive, worldwide, royalty-free license to use,
 * copy, modify, and distribute this software in source code or binary form for use
 * in connection with the web services and APIs provided by Facebook.
 *
 * As with any software that integrates with the Facebook platform, your use of
 * this software is subject to the Facebook Developer Principles and Policies
 * [http://developers.facebook.com/policy/]. This copyright notice shall be
 * included in all copies or substantial portions of the software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 * COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package com.facebook.login;

import androidx.annotation.Nullable;
import com.facebook.AccessToken;
import com.facebook.AuthenticationToken;
import java.util.Set;

/** This class shows the results of a login operation. */
public class LoginResult {
  private final AccessToken accessToken;
  private final AuthenticationToken authenticationToken;
  private final Set<String> recentlyGrantedPermissions;
  private final Set<String> recentlyDeniedPermissions;

  /**
   * The constructor.
   *
   * @param accessToken The new access token.
   * @param recentlyGrantedPermissions The recently granted permissions.
   * @param recentlyDeniedPermissions The recently denied permissions.
   */
  public LoginResult(
      AccessToken accessToken,
      Set<String> recentlyGrantedPermissions,
      Set<String> recentlyDeniedPermissions) {
    this(accessToken, null, recentlyGrantedPermissions, recentlyDeniedPermissions);
  }

  /**
   * The constructor.
   *
   * @param accessToken The new access token.
   * @param authenticationToken The new authentication token
   * @param recentlyGrantedPermissions The recently granted permissions.
   * @param recentlyDeniedPermissions The recently denied permissions.
   */
  public LoginResult(
      AccessToken accessToken,
      @Nullable AuthenticationToken authenticationToken,
      Set<String> recentlyGrantedPermissions,
      Set<String> recentlyDeniedPermissions) {
    this.accessToken = accessToken;
    this.authenticationToken = authenticationToken;
    this.recentlyGrantedPermissions = recentlyGrantedPermissions;
    this.recentlyDeniedPermissions = recentlyDeniedPermissions;
  }

  /**
   * Getter for the new access token.
   *
   * @return the new access token.
   */
  public AccessToken getAccessToken() {
    return accessToken;
  }

  /**
   * Getter for the new AuthenticationToken.
   *
   * @return the new id token or AuthenticationToken.
   */
  public AuthenticationToken getAuthenticationToken() {
    return authenticationToken;
  }

  /**
   * Getter for the recently granted permissions.
   *
   * @return the recently granted permissions.
   */
  public Set<String> getRecentlyGrantedPermissions() {
    return recentlyGrantedPermissions;
  }

  /**
   * Getter for the recently denied permissions.
   *
   * @return the recently denied permissions.
   */
  public Set<String> getRecentlyDeniedPermissions() {
    return recentlyDeniedPermissions;
  }
}
